ytree\.arbor\.arbor\.CatalogArbor
=================================

.. currentmodule:: ytree.arbor.arbor

.. autoclass:: CatalogArbor

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~CatalogArbor.__init__
      ~CatalogArbor.add_alias_field
      ~CatalogArbor.add_analysis_field
      ~CatalogArbor.add_derived_field
      ~CatalogArbor.is_grown
      ~CatalogArbor.is_setup
      ~CatalogArbor.save_arbor
      ~CatalogArbor.select_halos
      ~CatalogArbor.set_selector
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~CatalogArbor.arr
      ~CatalogArbor.box_size
      ~CatalogArbor.field_info
      ~CatalogArbor.hubble_constant
      ~CatalogArbor.quan
      ~CatalogArbor.size
      ~CatalogArbor.trees
      ~CatalogArbor.unit_registry
   
   